==> alfresco-remote-api-17.107-sources.jar: org/alfresco/opencmis/BrowserCMISDispatcher.java <==
/*
 * #%L
 * Alfresco Remote API
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.opencmis;

import javax.servlet.http.HttpServlet;

import org.alfresco.opencmis.CMISDispatcherRegistry.Binding;
import org.apache.chemistry.opencmis.server.impl.browser.CmisBrowserBindingServlet;

/**
 * Dispatches OpenCMIS requests to the OpenCMIS Browser Binding servlet.
 * 
 * @author steveglover
 *
 */
public class BrowserCMISDispatcher extends CMISServletDispatcher
{
    @Override
    protected Binding getBinding()
    {
    	return Binding.browser;
    }

	protected HttpServlet getServlet()
	{
		HttpServlet servlet = new CmisBrowserBindingServlet();
		return servlet;
	}
}

==> alfresco-remote-api-23.7.0.9-sources.jar: org/alfresco/opencmis/BrowserCMISDispatcher.java <==
/*
 * #%L
 * Alfresco Remote API
 * %%
 * Copyright (C) 2005 - 2023 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.opencmis;

import jakarta.servlet.http.HttpServlet;

import org.alfresco.opencmis.CMISDispatcherRegistry.Binding;
import org.apache.chemistry.opencmis.server.impl.browser.CmisBrowserBindingServlet;

/**
 * Dispatches OpenCMIS requests to the OpenCMIS Browser Binding servlet.
 * 
 * @author steveglover
 *
 */
public class BrowserCMISDispatcher extends CMISServletDispatcher
{
    @Override
    protected Binding getBinding()
    {
    	return Binding.browser;
    }

	protected HttpServlet getServlet()
	{
		HttpServlet servlet = new CmisBrowserBindingServlet();
		return servlet;
	}
}
